@@ -4,7 +4,6 @@ import logging
 import types
 
 from asyncio.futures import Future
-from asyncio.log import logger
 from asyncio.queues import Queue
 from asyncio.streams import StreamReader
 
@@ -23,6 +22,7 @@ from .exceptions import (
         TimeoutError,
         TransactionError,
 )
+from .log import logger
 from .replies import (
         BlockingPopReply,
         ClientListReply,
@@ -229,7 +229,7 @@ class PostProcessors:
                 return (yield from result.asset())
             return '_asset', set, as_set
 
-        elif return_type == DictReply:
+        elif return_type in (DictReply, ZRangeReply):
             @asyncio.coroutine
             def as_dict(protocol, result):
                 result = yield from original_post_processor(protocol, result)
@@ -770,7 +770,7 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
 
     def _encode_int(self, value:int) -> bytes:
         """ Encodes an integer to bytes. (always ascii) """
-        if value < 1000: # For small values, take pre-encoded string.
+        if 0 < value < 1000: # For small values, take pre-encoded string.
             return _SMALL_INTS[value]
         else:
             return str(value).encode('ascii')
@@ -860,7 +860,7 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
 
     @asyncio.coroutine
     def _handle_item(self, cb):
-        c = yield from self._reader.read(1)
+        c = yield from self._reader.readexactly(1)
         if c:
             yield from self._line_received_handlers[c](cb)
         else:
@@ -889,7 +889,7 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
             cb(None)
         else:
             # Read data
-            data = yield from self._reader.read(length)
+            data = yield from self._reader.readexactly(length)
             cb(data)
 
             # Ignore trailing newline.
@@ -1158,7 +1158,7 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
     @_query_command
     def move(self, key:NativeType, database:int) -> int:
         """ Move a key to another database """
-        return self._query(b'move', self.encode_from_native(key), self.encode_from_native(destination)) # TODO: test
+        return self._query(b'move', self.encode_from_native(key), self._encode_int(database)) # TODO: unittest
 
     @_query_command
     def rename(self, key:NativeType, newkey:NativeType) -> StatusReply:
@@ -1483,6 +1483,29 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
         return self._query(b'zrange', self.encode_from_native(key),
                     self._encode_int(start), self._encode_int(stop), b'withscores')
 
+    @_query_command
+    def zrevrange(self, key:NativeType, start:int=0, stop:int=-1) -> ZRangeReply:
+        """
+        Return a range of members in a reversed sorted set, by index.
+
+        You can do the following to receive the slice of the sorted set as a
+        python dict (mapping the keys to their scores):
+
+        ::
+
+            my_dict = yield protocol.zrevrange_asdict('myzset', start=10, stop=20)
+
+        or the following to retrieve it as a list of keys:
+
+        ::
+
+            zrange_reply = yield protocol.zrevrange('myzset', start=10, stop=20)
+            my_dict = yield zrange_reply.aslist()
+
+        """
+        return self._query(b'zrevrange', self.encode_from_native(key),
+                    self._encode_int(start), self._encode_int(stop), b'withscores')
+
     @_query_command
     def zrangebyscore(self, key:NativeType,
                 min:ZScoreBoundary=ZScoreBoundary.MIN_VALUE,
@@ -1714,9 +1737,9 @@ class RedisProtocol(asyncio.Protocol, metaclass=_RedisProtocolMeta):
         return self._pubsub_method('psubscribe', patterns)
 
     @_command
-    def _punsubscribe(self, patterns:ListOf(NativeType)) -> NoneType:
+    def _punsubscribe(self, patterns:ListOf(NativeType)) -> NoneType: # XXX: unittest
         """ Stop listening for messages posted to channels matching the given patterns """
-        self._pubsub_patterns -= set(channels)
+        self._pubsub_patterns -= set(patterns)
         return self._pubsub_method('punsubscribe', patterns)
 
     @asyncio.coroutine
